@@ -1,8 +1,8 @@
 # function to generate generalized Erdos-Renyi network 
 generate_ER <-
-  function(N                       , 
-           num_seed       = 2      , 
-           multiple_node  = 1      , 
+  function(N              = 1000, 
+           num_seed       = 2   , 
+           multiple_node  = 1   , 
            m              = 1   
   ){
     # N: number of nodes
@@ -16,5 +16,5 @@ generate_ER <-
     if ((m <= 0) || (num_seed <= 0) || (multiple_node <= 0))
         stop("The parameters must be positive")   
     
-    return(generate_net(N = N , num_seed = num_seed , multiple_node = multiple_node , m = m , alpha = 0, shape = 0))
+    return(generate_net(N = N , num_seed = num_seed , multiple_node = multiple_node , m = m , alpha = 0, s = 0))
   }
